Practice Problems - Write Code
-----------------------------------------------------

Please answer the following problems to the best
of your ability without any outside help. You can stop working on question after you worked on it for
about five minutes without solving it.

Please do not ask for external help and try your best to finish it!

Problems
==============

.. selectquestion:: fl-song-ps-sq-write
   :fromid: Classes_Basic_Song_ac
   :points: 10

.. selectquestion:: fl-cat-ps-sq-write
   :fromid: Classes_Basic_Cat_ac
   :points: 10

.. selectquestion:: fl-account-ps-sq-write
   :fromid: Classes_Basic_Account_ac
   :points: 10

.. selectquestion:: fl-fortuneteller-ps-sq-write
   :fromid: Classes_Basic_FortuneTeller_ac
   :points: 10

What to do next
============================
.. raw:: html

   <h4>Click on the following link to finish a posttest 👉 <b><a href="fl-posttest-cls.html">Post Test</b></h4>
